@@ -16,14 +16,15 @@ namespace Symfony\Component\Mercure\Twig;
 use Symfony\Component\HttpFoundation\RequestStack;
 use Symfony\Component\Mercure\Authorization;
 use Symfony\Component\Mercure\HubRegistry;
-use Twig\Attribute\AsTwigFunction;
+use Twig\Extension\AbstractExtension;
+use Twig\TwigFunction;
 
 /**
  * Registers the Twig helper function.
  *
  * @author Kévin Dunglas <kevin@dunglas.fr>
  */
-final class MercureExtension
+final class MercureExtension extends AbstractExtension
 {
     public function __construct(
         private readonly HubRegistry $hubRegistry,
@@ -32,13 +33,17 @@ final class MercureExtension
     ) {
     }
 
+    public function getFunctions(): array
+    {
+        return [new TwigFunction('mercure', $this->mercure(...))];
+    }
+
     /**
      * @param string|string[]|null                                                                                                                       $topics  A topic or an array of topics to subscribe for. If this parameter is omitted or `null` is passed, the URL of the hub will be returned (useful for publishing in JavaScript).
      * @param array{subscribe?: string[]|string, publish?: string[]|string, additionalClaims?: array<string, mixed>, lastEventId?: string, hub?: string} $options The options to pass to the JWT factory
      *
      * @return string The URL of the hub with the appropriate "topic" query parameters (if any)
      */
-    #[AsTwigFunction('mercure')]
     public function mercure(string|array|null $topics = null, array $options = []): string
     {
         $hub = $options['hub'] ?? null;
