@@ -23,11 +23,8 @@ class UpdateTest extends TestCase
 {
     /**
      * @dataProvider updateProvider
-     *
-     * @param mixed $topics
-     * @param mixed $data
      */
-    public function testCreateUpdate($topics, $data, bool $private = false, string $id = null, string $type = null, int $retry = null)
+    public function testCreateUpdate($topics, $data, bool $private = false, ?string $id = null, ?string $type = null, ?int $retry = null)
     {
         $update = new Update($topics, $data, $private, $id, $type, $retry);
         $this->assertSame((array) $topics, $update->getTopics());
@@ -45,12 +42,4 @@ class UpdateTest extends TestCase
             [['https://mercure.rocks', 'https://github.com/dunglas/mercure'], 'payload'],
         ];
     }
-
-    public function testInvalidTopic()
-    {
-        $this->expectException(\InvalidArgumentException::class);
-
-        // @phpstan-ignore-next-line
-        new Update(1, 'data');
-    }
 }
